# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from ..core.pydantic_utilities import pydantic_v1
from .filter_model import FilterModel
from .time_dimension_model import TimeDimensionModel


class QueryModel(pydantic_v1.BaseModel):
    measures: typing.Optional[typing.List[str]] = None
    time_dimensions: typing.Optional[typing.List[TimeDimensionModel]] = pydantic_v1.Field(
        alias="timeDimensions", default=None
    )
    dimensions: typing.Optional[typing.List[str]] = None
    filters: typing.Optional[typing.List[FilterModel]] = None
    limit: typing.Optional[int] = None

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}
